[APPDB] Assorted spelling fixes

Francois Gouget fgouget at free.fr
Tue Oct 24 17:57:21 CDT 2006


Changelog:

 * README
   appsubmit.php
   testResults.php
   admin/adminTestResults.php
   cron/cleanup.php
   help/maintainer_guidelines.help
   help/maintainer_ratings.help
   include/application.php
   include/bugs.php
   include/distribution.php
   include/image.php
   include/monitor.php
   include/screenshot.php
   include/session.php
   include/testData.php
   include/url.php
   include/version.php
   unit_test/test_user.php

   Francois Gouget <fgouget at free.fr>
   Assorted spelling fixes.

-- 
Francois Gouget <fgouget at free.fr>              http://fgouget.free.fr/
     We are Pentium of Borg. You will be approximated. Division is futile.
-------------- next part --------------
Index: README
===================================================================
RCS file: /home/wine/appdb/README,v
retrieving revision 1.8
diff -u -p -r1.8 README
--- README	10 Jan 2005 22:54:04 -0000	1.8
+++ README	24 Oct 2006 22:54:34 -0000
@@ -32,7 +32,7 @@ To install locally for testing/hacking:
    short_open_tag 0
    register_long_arrays 0
    magic_quotes_gpc 0
- Or ensure your appdb directory has AllowOveride' set to 'All' inside 
+ Or ensure your appdb directory has AllowOverride' set to 'All' inside 
  httpd.conf to let .htaccess set these settings.
  
 # An AppDB admin user has been automatically created while running 
@@ -42,7 +42,7 @@ To install locally for testing/hacking:
   You should change the password as soon as possible!
 
 #------------------------------------------------------------------------#
-You can create ether set up a real bugzilla database or a fake one 
+You can create either set up a real bugzilla database or a fake one 
 
 # cd tables, run ./create_bugzilla_tables to create the fake bugzilla tables
 #------------------------------------------------------------------------#
Index: testResults.php
===================================================================
RCS file: /home/wine/appdb/testResults.php,v
retrieving revision 1.20
diff -u -p -r1.20 testResults.php
--- testResults.php	31 Aug 2006 02:39:09 -0000	1.20
+++ testResults.php	24 Oct 2006 22:54:34 -0000
@@ -30,7 +30,7 @@ if ($aClean['sSub'])
         $oTest->iVersionId = $aClean['iVersionId'];
     $errors = "";
 
-    // Submit or Resubmit the new testing results
+    // Submit or Resubmit the new test results
     if (($aClean['sSub'] == 'Submit') || ($aClean['sSub'] == 'Resubmit'))
     {
         $errors = $oTest->CheckOutputEditorInput($_REQUEST);
@@ -62,7 +62,7 @@ if ($aClean['sSub'])
         }
     }
 
-    // Delete testing results
+    // Delete test results
     if ($aClean['sSub'] == 'Delete')
     {
         if(is_numeric($aClean['iTestingId']))
@@ -77,7 +77,7 @@ if ($aClean['sSub'])
     // is this an old test?
     if(is_numeric($aClean['iTestingId']))
     {
-        // make sure the user has permission to view this testing result
+        // make sure the user has permission to view this test result
         $oVersion = new Version($oTest->iVersionId);
         if(!$_SESSION['current']->hasPriv("admin") && 
            !$_SESSION['current']->hasAppVersionModifyPermission($oVersion)&&
@@ -100,30 +100,30 @@ if ($aClean['sSub'])
         switch($oTest->sQueued)
         {
         case "new":
-            apidb_header("Submit new testing results for ".$sVersionInfo);
+            apidb_header("Submit new test results for ".$sVersionInfo);
             $oTest->sTestedDate = date('Y-m-d H:i:s');
             break;
         case "true":
-            apidb_header("Edit new testing results for ".$sVersionInfo);
+            apidb_header("Edit new test results for ".$sVersionInfo);
             break;
         case "rejected":
-            apidb_header("Resubmit testing results for ".$sVersionInfo);
+            apidb_header("Resubmit test results for ".$sVersionInfo);
             break;
         case "False":
-            apidb_header("Edit testing results for ".$sVersionInfo);
+            apidb_header("Edit test results for ".$sVersionInfo);
             break;
         default:
-            apidb_header("Edit testing results for ");
+            apidb_header("Edit test results for ");
         }
         echo '<form name="sQform" action="'.$_SERVER['PHP_SELF'].'" method="post" enctype="multipart/form-data">',"\n";
 
 
         //help
-        echo "<p>This is the screen for inputting testing information so that others looking at the database will know \n";
-        echo "what was working or a particular release of Wine.</p>\n";
+        echo "<p>This is the screen for inputing test information so that others looking at the database will know \n";
+        echo "what was working on a particular release of Wine.</p>\n";
         echo "<p>Please be as detailed as you can.</p>\n";
-        echo "<p>If you can not find your distribution in the list of existing distributions, please add it in the \n";
-        echo "field provided.</p>\n\n";        
+        echo "<p>If you cannot find your distribution in the list of existing distributions, please add it in the \n";
+        echo "provided field.</p>\n\n";        
 
         if(!empty($errors))
         {
@@ -133,7 +133,7 @@ if ($aClean['sSub'])
             echo '<p></p>',"\n";
         }
    
-        // View Testing Details
+        // View Test Details
         $oTest->OutputEditor($aClean['sDistribution'],true);
 
         echo '<a href="'.BASE."appview.php?iVersionId=".$oTest->iVersionId.'">Back to Version</a>';
@@ -166,39 +166,39 @@ if ($aClean['sSub'])
         util_redirect_and_exit($_SERVER['PHP_SELF']);
     } 
 } 
-else // if ($aClean['sSub']) is not defined, display the Testing results queue page 
+else // if ($aClean['sSub']) is not defined, display the Test results queue page 
 {
-    apidb_header("Testing Results");
+    apidb_header("Test Results");
 
-    // Get queued testing results.
+    // Get queued test results.
     $oTest = new TestData();
     $hResult = $oTest->getTestingQueue("true");
 
     if(!$hResult)
     {
         // no Tests in queue
-        echo html_frame_start("Submitted Testing Results","90%");
-        echo '<p><b>The Submitted Testing Results Queue is empty.</b></p>',"\n";
+        echo html_frame_start("Submitted Test Results","90%");
+        echo '<p><b>The Submitted Test Results Queue is empty.</b></p>',"\n";
         echo html_frame_end("&nbsp;");         
     }
     else
     {
         // help
         echo "<div align=center><table width='90%' border=0 cellpadding=3 cellspacing=0><tr><td>\n\n";
-        echo "<p>This is the list of Test Results waiting for submition, or to be deleted.</p>\n";
+        echo "<p>This is the list of Test Results waiting for submission, or to be deleted.</p>\n";
         echo "<p>To view a submission, click on its name. From that page you can delete or edit and\n";
         echo "re-submit it into the AppDB .<br>\n";
         echo "</td></tr></table></div>\n\n";
 
-        $oTest->ShowListofTests($hResult,"Submitted Testing Results");
+        $oTest->ShowListofTests($hResult,"Submitted Test Results");
     }
-    // Get rejected testing results.
+    // Get rejected test results.
     $hResult = $oTest->getTestingQueue("rejected");
 
     if(!$hResult || !mysql_num_rows($hResult))
     {
         //no Test Results in queue
-        echo html_frame_start("Rejected Testing Results","90%");
+        echo html_frame_start("Rejected Test Results","90%");
         echo '<p><b>The Rejected Testng Results Queue is empty.</b></p>',"\n";
         echo html_frame_end("&nbsp;");         
     }
@@ -206,12 +206,12 @@ else // if ($aClean['sSub']) is not defi
     {
         //help
         echo "<div align=center><table width='90%' border=0 cellpadding=3 cellspacing=0><tr><td>\n\n";
-        echo "<p>This is the list of Rejected Test Results waiting for re-submition or deletion.</p>\n";
+        echo "<p>This is the list of Rejected Test Results waiting for re-submission or deletion.</p>\n";
         echo "<p>To view a submission, click on its name. From that page you can delete or edit and re-submit it into \n";
         echo "the AppDB .<br>\n";
         echo "</td></tr></table></div>\n\n";
 
-        $oTest->ShowListofTests($hResult,"Rejected Testing Results");
+        $oTest->ShowListofTests($hResult,"Rejected Test Results");
     }
 }
 apidb_footer();       
Index: admin/adminTestResults.php
===================================================================
RCS file: /home/wine/appdb/admin/adminTestResults.php,v
retrieving revision 1.16
diff -u -p -r1.16 adminTestResults.php
--- admin/adminTestResults.php	30 Aug 2006 22:27:07 -0000	1.16
+++ admin/adminTestResults.php	24 Oct 2006 22:54:34 -0000
@@ -31,18 +31,18 @@ if ($aClean['sSub'])
             $oTest = new testData($aClean['iTestingId']);
             $oTest->GetOutputEditorValues($_REQUEST);
 
-            if($aClean['sSub'] == 'Submit')        // submit the testing results
+            if($aClean['sSub'] == 'Submit')        // submit the test results
             {
                 $oTest->update(true);
                 $oTest->unQueue();
-            } else if($aClean['sSub'] == 'Save')   // save the testing results
+            } else if($aClean['sSub'] == 'Save')   // save the test results
             {
                 $oTest->update();
-            } else if($aClean['sSub'] == 'Reject') // reject testing results
+            } else if($aClean['sSub'] == 'Reject') // reject test results
             {
                 $oTest->update(true);
                 $oTest->Reject();
-            } else if($aClean['sSub'] == 'Delete') // delete testing results
+            } else if($aClean['sSub'] == 'Delete') // delete test results
             {
                 $oTest->delete();
             }
@@ -64,18 +64,18 @@ if ($aClean['sSub'])
         switch($oTest->sQueued)
         {
         case "true":
-            apidb_header("Edit new testing results for ".$sVersionInfo);
+            apidb_header("Edit new test results for ".$sVersionInfo);
             break;
         case "rejected":
-            apidb_header("Edit rejected testing results for ".$sVersionInfo);
+            apidb_header("Edit rejected test results for ".$sVersionInfo);
             break;
         case "false":
-            apidb_header("Edit testing results for ".$sVersionInfo);
+            apidb_header("Edit test results for ".$sVersionInfo);
             break;
         }
 
         echo '<form name="sQform" action="'.$_SERVER['PHP_SELF'].'" method="post" enctype="multipart/form-data">',"\n";
-        // View Testing Details
+        // View Test Details
         echo "<table width='100%' border=0 cellpadding=2 cellspacing=0>\n";
 
         //help
@@ -83,21 +83,21 @@ if ($aClean['sSub'])
         switch($oTest->sQueued)
         {
         case "false":
-            echo "<p>This Testing result has already been verified and accepted int the database. \n";
-            echo "You can edit the entry and the save it back to the database by clicking on save. \n";
+            echo "<p>This Test result has already been verified and accepted into the database. \n";
+            echo "You can edit the entry and save it back to the database by clicking on save. \n";
             break;
         case "true":
-            echo "<p>This Testing result has not yet been and accepted into the database. \n";
-            echo "You can edit the entry and ether submit it into the database by clicking on Submit or you can reject it \n";
+            echo "<p>This Test result has not yet been and accepted into the database. \n";
+            echo "You can edit the entry and either submit it into the database by clicking on Submit, or you can reject it \n";
             echo "for further editing by the submitter by clicking on Reject. \n";
             break;
         case "rejected":
-            echo "<p>This Testing result has been rejected and is awaiting further information from the submitter. \n";
-            echo "You can edit the entry and ether submit it into the database by clicking on Submit or you can save it \n";
+            echo "<p>This Test result has been rejected and is awaiting further information from the submitter. \n";
+            echo "You can edit the entry and either submit it into the database by clicking on Submit, or you can save it \n";
             echo "for further editing by the submitter by clicking on Save. \n";
             break;
         }
-        echo "<p>Click delete to remove it entirly from the database. An email will automatically be sent to the\n";
+        echo "<p>Click delete to remove it entirely from the database. An email will automatically be sent to the\n";
         echo "submitter to let them know the item was deleted.</p>\n\n";        
         echo "</td></tr></table></div>\n\n";    
 
@@ -143,40 +143,40 @@ if ($aClean['sSub'])
         util_redirect_and_exit($_SERVER['PHP_SELF']);
     } 
 }
-else // if ($aClean['sSub']) is not defined, display the Testing results queue page 
+else // if ($aClean['sSub']) is not defined, display the Test results queue page 
 {
     $oTest = new TestData();
-    apidb_header("Testing Results");
+    apidb_header("Test Results");
 
-    // Get queued testing results.
+    // Get queued test results.
 
     $hResult = $oTest->getTestingQueue("true");
     if(!$hResult)
     {
          //no apps in queue
-        echo html_frame_start("Submitted Testing Results","90%");
-        echo '<p><b>The Submitted Testing Results Queue is empty.</b></p>',"\n";
+        echo html_frame_start("Submitted Test Results","90%");
+        echo '<p><b>The Submitted Test Results Queue is empty.</b></p>',"\n";
         echo html_frame_end("&nbsp;");         
     }
     else
     {
         //help
         echo "<div align=center><table width='90%' border=0 cellpadding=3 cellspacing=0><tr><td>\n\n";
-        echo "<p>This is the list of test results waiting for submition, rejection or deletion.</p>\n";
+        echo "<p>This is the list of test results waiting for submission, rejection or deletion.</p>\n";
         echo "<p>To view a submission, click on its name. From that page you can Submit it into \n";
         echo "the AppDB reject it or delete it.<br>\n";
         echo "</td></tr></table></div>\n\n";
 
-        $oTest->ShowListofTests($hResult,"Submitted Testing Results");
+        $oTest->ShowListofTests($hResult,"Submitted Test Results");
     }
 
-    // Get rejected testing results.
+    // Get rejected test results.
     $hResult = $oTest->getTestingQueue("rejected");
     if(!$hResult || !mysql_num_rows($hResult))
     {
         //no rejected test results in queue
-        echo html_frame_start("Rejected Testing Results","90%");
-        echo '<p><b>The Rejected Testing Results Queue is empty.</b></p>',"\n";
+        echo html_frame_start("Rejected Test Results","90%");
+        echo '<p><b>The Rejected Test Results Queue is empty.</b></p>',"\n";
         echo html_frame_end("&nbsp;");         
     }
     else
@@ -188,7 +188,7 @@ else // if ($aClean['sSub']) is not defi
         echo "the AppDB, edit and save it or delete it.<br>\n";
         echo "</td></tr></table></div>\n\n";
 
-        $oTest->ShowListofTests($hResult,"Rejected Testing Results");
+        $oTest->ShowListofTests($hResult,"Rejected Test Results");
     }
 }
 apidb_footer();       
Index: cron/cleanup.php
===================================================================
RCS file: /home/wine/appdb/cron/cleanup.php,v
retrieving revision 1.31
diff -u -p -r1.31 cleanup.php
--- cron/cleanup.php	24 Jul 2006 16:20:40 -0000	1.31
+++ cron/cleanup.php	24 Oct 2006 22:54:34 -0000
@@ -30,7 +30,7 @@ if($hUsersToWarn)
     {
         $oUser = new User($oRow->userid);
 
-        /* if we get back true the user was warned and flaged as being warned */
+        /* if we get back true the user was warned and flagged as being warned */
         /* if we get back false we didn't warn the user and didn't flag the user as warned */
         /*  because they have data associated with their account */
         if($oUser->warnForInactivity())
@@ -56,7 +56,7 @@ if($hUsersToDelete)
             deleteUser($oRow->userid);
         } else
         {
-            /* is the user a maintainer?  if so remove their maintainer privilages */
+            /* is the user a maintainer?  if so remove their maintainer privileges */
             if($oUser->isMaintainer())
             {
                 Maintainer::deleteMaintainer($oUser);
Index: help/maintainer_guidelines.help
===================================================================
RCS file: /home/wine/appdb/help/maintainer_guidelines.help,v
retrieving revision 1.5
diff -u -p -r1.5 maintainer_guidelines.help
--- help/maintainer_guidelines.help	6 Jul 2006 17:27:54 -0000	1.5
+++ help/maintainer_guidelines.help	24 Oct 2006 22:54:34 -0000
@@ -3,11 +3,11 @@
 <h3>Maintainers Guidelines</h3>
 
 <p>
-This page gives informations on how to maintain an application once being an application maintainer. If you are looking on informations on how to become an application maintainer, this topic is covered in the <a href="./?sTopic=appdb_faq" style="cursor: help">FAQ</a>.
+This page gives information on how to maintain an application once you are an application maintainer. If you are looking for information on how to become an application maintainer, this topic is covered in the <a href="./?sTopic=appdb_faq" style="cursor: help">FAQ</a>.
 </p>
 
 <p>
-Getting a (super) maintainer gives you certain rights on the Application Database. However as you may know, with great power, comes great responsibility...
+Becoming a (super) maintainer gives you certain rights on the Application Database. However as you may know, with great power, comes great responsibility...
 </p>
 
 <p>An application maintainer is someone who runs the application regularly and who is willing to be active in reporting regressions with newer versions of Wine and to help other users run this application under Wine.</p>
@@ -22,14 +22,14 @@ You are expected to:
 You will:
 <ul>
 <li>Receive an email anytime a comment is posted or deleted for the application or the application information is modified</li>
-<li>Be able to modify all aspects of your application(s) and version(s), including description, screenshots, how-to's, notes, comments, etc.</li>
+<li>Be able to modify all aspects of your application(s) and version(s), including the description, screenshots, how-tos, notes, comments, etc.</li>
 </ul>
 
 <br />
 
 <h4>Application overview page guidlines</h4>
 <p><i>N.B. Only super maintainers can change the general description of an application.</i><br />
-You can edit an application overview page by clicking on the "Edit Application" button in an application overview page. You'll be then presented with a form whose fields are explained thereafter.
+You can edit an application overview page by clicking on the "Edit Application" button in the application overview page. You will be then presented with a form whose fields are explained thereafter.
 <ul>
 <li>
 Application name should be checked against official application name and should not contain the vendor's name.
@@ -38,10 +38,10 @@ Application name should be checked again
 Application vendor should be set correctly. If the vendor is missing, please contact <a href="mailto:appdb at winehq.org">appdb at winehq.org</a>.
 </li>
 <li>
-Keywords are used by the search engine, you don't need to repeat the application's name but you are encouraged to provide some keywords in this field.
+Keywords are used by the search engine. You don't need to repeat the application's name but you are encouraged to provide some keywords in this field.
 </li>
 <li>
-Description should describe the application in a general manner (what it does). Wine and version specific considerations goes in version-specific pages (described below). If you want to add more than a short sentence, please add a cariage return after the first sentence as it will be used when showing application summary in the search engine, top-25 page and so on. <br />You are encouraged to make use of the template provided for application description; you can copy/paste this template from the "<a href="../appsubmit.php?iAppType=application">Submit application page</a>".
+Description should describe the application in a general manner (what it does). THe Wine and version specific considerations go in version-specific pages (described below). If you want to add more than a short sentence, please add a cariage return after the first sentence as it will be used when showing the application summary in the search engine, top-25 page and so on. <br />You are encouraged to make use of the template provided for application description; you can copy/paste this template from the "<a href="../appsubmit.php?iAppType=application">Submit application page</a>".
 </li>
 <li>
 Webpage should contain the home page for this application. Please remember that an URL starts with http://.
@@ -51,17 +51,17 @@ Webpage should contain the home page for
 
 <h4>Version page guidlines</h4>
 <p>
-You can edit a version page by clicking on the "Edit Version" button in any version page for which you are a (super) maintainer. You'll be then presented with a form whose fields are explained thereafter.
+You can edit a version page by clicking on the "Edit Version" button in any version page for which you are a (super) maintainer. You will then be presented with a form whose fields are explained thereafter.
 <ul>
 <li>
-Version name should be checked against official version name. However if you feel that two minor revision of an application will share the same problems or success, you are encouraged to use wildcards in the version number to don't fill the database with hundreds of versions. For example if you know that Adobe Acrobat 6.0, 6.01 and 6.1 are about the same application, just choose 6.x as a version name. You can however use the full version name in an history table in the description field (see below).
+Version name should be checked against official version name. However if you feel that two minor revisions of an application will share the same problems or success, you are encouraged to use wildcards in the version number to avoid cluttering the database with hundreds of versions. For example if you know that Adobe Acrobat 6.0, 6.01 and 6.1 are about the same application, just choose 6.x as a version name. You can however use the full version name in an history table in the description field (see below).
 </li>
 <li>
-Description should describe the application version and not be a repetition of the application description. Please use a short sentence as the first line of your description to describe what this version is and then add a cariage return after this first sentence as it will be used when showing version summary in the application page for example. <br />You are encouraged to make use of the template provided for version description; you can copy/paste this template from the "<a href="../appsubmit.php?sAppType=version">Submit version page</a>".<br />
-As you'll see in this template usefull informations to place in this field are the specification of what works and what doesn't in wine and you can also add what is called an history table to keep track of improvemetns and regression. Using the html editor described later in this document and the provided template it is easy to produce such a table which will contains columns like version number, wine version, installs, runs, rating. You can then use the styles drop down list of the editor to set the color of the row according to the rating (gold, silver, bronze or garbage). You can see an example <a href="../appview.php?iVersionId=2602">here</a>.
+Description should describe the application version and not be a repetition of the application description. Please use a short sentence as the first line of your description to describe what this version is, and then add a carriage return after this first sentence as it will be used when showing version summary, in the application page for example. <br />You are encouraged to make use of the template provided for version description; you can copy/paste this template from the "<a href="../appsubmit.php?sAppType=version">Submit version page</a>".<br />
+As you'll see in this template, useful information to place in this field is the specification of what works and what doesn't in wine. You can also add what is called an history table to keep track of improvements and regression. Using the html editor, described later in this document, and the provided template, it is easy to produce such a table which will contains columns with the version number, wine version, installs, runs, ratings. You can then use the styles drop down list of the editor to set the color of the row according to the rating (gold, silver, bronze or garbage). You can see an example <a href="../appview.php?iVersionId=2602">here</a>.
 </li>
 <li>
-Rating let's you rate how this version ran with the latest Wine version you tested it with. For rating definitions, please see this <a href="index.php?sTopic=maintainer_ratings">page</a>.
+Rating lets you rate how this version ran with the latest Wine version you tested. For rating definitions, please see this <a href="index.php?sTopic=maintainer_ratings">page</a>.
 </li>
 <li>
 Release is the latest release of Wine you tested this version with.
@@ -70,33 +70,33 @@ Release is the latest release of Wine yo
 
 <h4>Additional URLs guidlines</h4>
 <p>
-In both application and version editing page you can add additional URLs. These URLs can for example help the user find native alternatives for this application (in application overview page) or find specific dll (in version page).
+In both application and version editing pages you can add additional URLs. These URLs can, for example, help the user find native alternatives for this application (in application overview page) or find specific dlls (in version page).
 </p>
 
 <h4>Screenshots guidlines</h4>
 <p>
-As a maintainer you are encouraged to provide screenshots for the versions you tested under Wine. To add a screenshot, simply click on the screenshot thumbnail you'll find in the version page you want to provide a screenshot for.
+As a maintainer you are encouraged to provide screenshots for the versions you tested under Wine. To add a screenshot, simply click on the screenshot thumbnail in the version page.
 </p>
 
 <h4>Notes guidlines</h4>
 <p>
-In the version page you can add, edit and delete notes for the versions you maintain. Just click on "Add note" button.
+In the version page you can add, edit and delete notes for the versions you maintain. Just click on the "Add note" button.
 </p>
 
 
 <h4>How-to guidlines</h4>
 <p>
-How-to's are just a special kind of notes. You can provide step-by-step explanations on how to install or run a specific version of the current application here. Please try to keep How-to's up to date (for example some steps might not be needed anymore using a more recent version of Wine).
+How-tos are just a special kind of notes. You can provide step-by-step explanations on how to install or run a specific version of the current application here. Please try to keep How-to's up to date (for example some steps might not be needed anymore using a more recent version of Wine).
 </p>
 
 <h4>Warnings guidlines</h4>
 <p>
-Warnings are just a special kind of note. Warnings appear in red and should catch the attention of the reader. If you are warning users agains potential data corruption for example, please keep the warning up-to-date if it is not true anymore using a recent Wine version (in this case you might choose to keep the warning and tell users that since Wine X.Y, this has been fixed).
+Warnings are just a special kind of note. Warnings appear in red to catch the attention of the reader. They can be used to warning users against potential data corruption for instance. Please keep the warning up-to-date, especially if it is not true anymore using a recent Wine version (in this case you might choose to keep the warning and tell users that since Wine X.Y, this has been fixed).
 </p>
 
 <h4>Comments guidlines</h4>
 <p>
-As a maintainer you are entitled to delete comments. Use this feature wisely and always explain why you deleted a comment. If a comment is useless or is not true anymore, you can safely delete it. Whenever you can, extract how-to's, other people's tests (for you test history table for example) from the comments and put it in your version's page and how-to notes.
+As a maintainer you are entitled to delete comments. Use this feature wisely and always explain why you deleted a comment. If a comment is useless or is not true anymore, you can safely delete it. Whenever you can, extract how-tos, other peoples tests (for your test history table for example) from the comments and put it in your versions page and how-to notes.
 </p>
 
 
Index: help/maintainer_ratings.help
===================================================================
RCS file: /home/wine/appdb/help/maintainer_ratings.help,v
retrieving revision 1.4
diff -u -p -r1.4 maintainer_ratings.help
--- help/maintainer_ratings.help	8 Feb 2006 03:19:40 -0000	1.4
+++ help/maintainer_ratings.help	24 Oct 2006 22:54:34 -0000
@@ -38,9 +38,9 @@ Application works, but it has some issue
 <li class="Garbage">Garbage</li>
 
 <p>
-An app gets this rating if it can not be used for the purpose it was designed.
+An app gets this rating if it cannot be used for the purpose it was designed for.
 There should be at least one bug report in bugzilla if an app gets this rating.
-Application doesn't start, or starts but has so many errors that it is nearly impossible to use it
+Application doesn't start, or starts but has so many errors that it is nearly impossible to use it.
 </p>
 
 </ul>
Index: include/application.php
===================================================================
RCS file: /home/wine/appdb/include/application.php,v
retrieving revision 1.74
diff -u -p -r1.74 application.php
--- include/application.php	30 Sep 2006 01:31:04 -0000	1.74
+++ include/application.php	24 Oct 2006 22:54:34 -0000
@@ -285,7 +285,7 @@ class Application {
                             "false",  str_replace(" *** ","",$this->sKeywords), $this->iAppId))
         {
             $this->sQueued = 'false';
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             $this->mailSubmitter();
             $this->SendNotificationMail();
         }
@@ -304,11 +304,11 @@ class Application {
                             "rejected", $this->iAppId))
         {
             $this->sQueued = 'rejected';
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             $this->mailSubmitter("reject");
             $this->SendNotificationMail("reject");
 
-            // the application has been rejectedd
+            // the application has been rejected
             addmsg("The application has been rejected.", "green");
         }
     }
@@ -321,7 +321,7 @@ class Application {
                             "true", $this->iAppId))
         {
             $this->sQueued = 'true';
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             $this->SendNotificationMail();
 
             // the application has been re-queued
@@ -343,7 +343,7 @@ class Application {
             case "add":
                 $sSubject =  "Submitted application accepted";
                 $sMsg  = "The application you submitted (".$oApp->sName." ".$this->sName.") has been accepted.";
-                $sMsg .= "Administrators Responce:\n";
+                $sMsg .= "Administrators Response:\n";
             break;
             case "reject":
                 $sSubject =  "Submitted application rejected";
Index: include/bugs.php
===================================================================
RCS file: /home/wine/appdb/include/bugs.php,v
retrieving revision 1.16
diff -u -p -r1.16 bugs.php
--- include/bugs.php	6 Sep 2006 01:43:30 -0000	1.16
+++ include/bugs.php	24 Oct 2006 22:54:34 -0000
@@ -180,7 +180,7 @@ class Bug {
                             "false", $this->iLinkId))
         {
             $this->bQueued = false;
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             $this->mailSubmitter();
             $this->SendNotificationMail();
             // the Bug has been unqueued
Index: include/image.php
===================================================================
RCS file: /home/wine/appdb/include/image.php,v
retrieving revision 1.7
diff -u -p -r1.7 image.php
--- include/image.php	31 Aug 2006 02:23:01 -0000	1.7
+++ include/image.php	24 Oct 2006 22:54:34 -0000
@@ -66,7 +66,7 @@ class Image {
      * isLoaded()
      * This function should always be checked after loading a file
      * with the constructor. Returns true if the image has been
-     * succesfully loaded.
+     * successfully loaded.
      */ 
     function isLoaded()
     {
@@ -236,8 +236,8 @@ class Image {
         $g = hexdec(substr($sBorderColor, 3, 2));
         $b = hexdec(substr($sBorderColor, 5, 2));
         
-        /* We multiply the border width by two because there are are borders
-        at both sides */
+        /* We multiply the border width by two because there are borders
+         on both sides */
         // GD 2.x
         if(function_exists("imagecreatetruecolor"))
         {
@@ -277,7 +277,7 @@ class Image {
     /**
      * add_watermark()
      *
-     * $watermark is a image resource identifier to any image resource.
+     * $watermark is an image resource identifier to any image resource.
      *
      * $min_mark_wwidth and $min_mark_height are the minimum sizes of the
      * destination image before the watermark is added. If none are set
@@ -307,10 +307,10 @@ class Image {
     }
     
     /**
-     * Output the image to a file set with $store.
+     * Save the image to a file set with $store.
      *
      * $iType is optional and is set like the second index of getimagesize().
-     * If none (or 0) is set the orginal type of the file is used.
+     * If none (or 0) is set the original type of the file is used.
      * If $store is not give, the current file name will be used.
      * $quality is the jpeg output quality (100 best, 0 worst). Default is 75
      */
@@ -325,16 +325,16 @@ class Image {
         {
             case 2:
             imagejpeg($this->oImage, $sOutputFilename, $iQuality);
-            $this->set_debuglog("Outputed file as jpeg to $sOutputFilename");
+            $this->set_debuglog("Saved file as jpeg to $sOutputFilename");
             break;
             
             case 3:
             imagepng($this->oImage, $sOutputFilename);
-            $this->set_debuglog("Outputed file as png to $sOutputFilename");
+            $this->set_debuglog("Saved file as png to $sOutputFilename");
             break;
             
             default:
-            $this->set_debuglog("Unkown output type");
+            $this->set_debuglog("Unknown output type");
             return;
         }
         
@@ -347,7 +347,7 @@ class Image {
      * If $bHeader is true a Content-type header with the correct type
      * is set.
      * $iType is optional and is set like the second index of getimagesize().
-     * If none (or 0) is set the orginal type of the file is used.
+     * If none (or 0) is set the original type of the file is used.
      *
      * $iQuality is the jpeg output quality (100 best, 0 worst)
      */  
@@ -373,7 +373,7 @@ class Image {
             break;
             
             default:
-            $this->set_debuglog("Unkown output type");
+            $this->set_debuglog("Unknown output type");
         }
     }
     
@@ -430,7 +430,7 @@ class ImageResource extends Image {
         $this->iHeight = imagesy($oImage);
         $this->iType = $iType;
         
-        $this->set_debuglog("New image class created with as $oImage as"
+        $this->set_debuglog("New image class created with $oImage as"
                           ." image resource and $iType as type. Dimensions"
                           ." {$this->iWidth}x{$this->iHeight}");
     }
Index: include/monitor.php
===================================================================
RCS file: /home/wine/appdb/include/monitor.php,v
retrieving revision 1.8
diff -u -p -r1.8 monitor.php
--- include/monitor.php	6 Jul 2006 17:27:54 -0000	1.8
+++ include/monitor.php	24 Oct 2006 22:54:34 -0000
@@ -107,12 +107,12 @@ class Monitor {
                     $sSubject = "Monitor for ".$sAppName;
                     $sSubject .= " added: ".$_SESSION['current']->sRealname;
                     $sMsg .= APPDB_ROOT."appview.php?iVersionId=".$this->iVersionId."\n";
-                    addmsg("You will now recieve an email whenever changes are made to this Application version.", "green");
+                    addmsg("You will now receive an email whenever changes are made to this Application version.", "green");
                 } else
                 {
                     $sSubject = "Monitor for ".$sAppName." added: ".$_SESSION['current']->sRealname;
                     $sMsg .= APPDB_ROOT."appview.php?iAppId=".$this->iAppid."\n";
-                    addmsg("You will now recieve an email whenever changes are made to this Application.", "green");
+                    addmsg("You will now receive an email whenever changes are made to this Application.", "green");
                 } 
             break;
             case "delete":
@@ -121,12 +121,12 @@ class Monitor {
                     $sSubject = "Monitor for ".$sAppName;
                     $sSubject .= " removed: ".$_SESSION['current']->sRealname;
                     $sMsg .= APPDB_ROOT."appview.php?iVersionId=".$this->iVersionId."\n";
-                    addmsg("You will no longer recieve an email whenever changes are made to this Application version.", "green");
+                    addmsg("You will no longer receive an email whenever changes are made to this Application version.", "green");
                 } else
                 {
                     $sSubject = "Monitor for ".$sAppName." removed: ".$_SESSION['current']->sRealname;
                     $sMsg .= APPDB_ROOT."appview.php?iAppId=".$this->iAppid."\n";
-                    addmsg("You will no longer recieve an email whenever changes are made to this Application.", "green");
+                    addmsg("You will no longer receive an email whenever changes are made to this Application.", "green");
                 } 
             break;
         }
Index: include/screenshot.php
===================================================================
RCS file: /home/wine/appdb/include/screenshot.php,v
retrieving revision 1.50
diff -u -p -r1.50 screenshot.php
--- include/screenshot.php	6 Sep 2006 01:42:25 -0000	1.50
+++ include/screenshot.php	24 Oct 2006 22:54:34 -0000
@@ -161,7 +161,7 @@ class Screenshot {
                             "false", $this->iScreenshotId))
         {
             $this->bQueued = false;
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             $this->mailSubmitter();
             $this->mailMaintainers();
             // the screenshot has been unqueued
@@ -195,7 +195,7 @@ class Screenshot {
     
     /**
      * This method generates a watermarked screenshot and thumbnail from the original file.
-     * Usefull when changing thumbnail, upgrading GD, adding an image, etc.
+     * Useful when changing thumbnail, upgrading GD, adding an image, etc.
      * Return false if an image could not be loaded.
      */
     function generate() 
Index: include/session.php
===================================================================
RCS file: /home/wine/appdb/include/session.php,v
retrieving revision 1.13
diff -u -p -r1.13 session.php
--- include/session.php	8 Jul 2006 21:49:49 -0000	1.13
+++ include/session.php	24 Oct 2006 22:54:34 -0000
@@ -5,7 +5,7 @@
  * sessions are stored in a mysql table
  */
 
-/* the number of days a session cookie is flaged to last */
+/* the number of days a session cookie is flagged to last */
 define(SESSION_DAYS_TO_EXPIRE, 2);
 
 class session
Index: include/url.php
===================================================================
RCS file: /home/wine/appdb/include/url.php,v
retrieving revision 1.9
diff -u -p -r1.9 url.php
--- include/url.php	13 Jul 2006 18:54:10 -0000	1.9
+++ include/url.php	24 Oct 2006 22:54:34 -0000
@@ -115,7 +115,7 @@ class Url {
         if(query_parameters("UPDATE appData SET queued = '?' WHERE id='?'",
                        "false", $this->iUrlId))
         {
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             $this->mailSubmitter();
             $this->SendNotificationMail();
             // the url has been unqueued
Index: unit_test/test_user.php
===================================================================
RCS file: /home/wine/appdb/unit_test/test_user.php,v
retrieving revision 1.7
diff -u -p -r1.7 test_user.php
--- unit_test/test_user.php	24 Jul 2006 16:20:40 -0000	1.7
+++ unit_test/test_user.php	24 Oct 2006 22:54:34 -0000
@@ -278,7 +278,7 @@ function test_user_update_password()
 }
 
 /*************************/
-/* Main testing routines */
+/* Main test routines */
 
 if(!test_user_create())
     echo "test_user_create() failed!\n";
@@ -317,7 +317,7 @@ include_once("test_maintainer.php");
 /* TODO: the rest of the user member functions we don't currently test */
 
 
-/* clean up the user we created during testing */
+/* clean up the user we created during the tests */
 /* so the unit test leaves no trace that it ran */
 $oUser = new User();
 


More information about the wine-patches mailing list
Index: appsubmit.php
===================================================================
RCS file: /home/wine/appdb/appsubmit.php,v
retrieving revision 1.56
diff -u -p -r1.56 appsubmit.php
--- appsubmit.php	12 Jul 2006 00:29:35 -0000	1.56
+++ appsubmit.php	24 Oct 2006 22:54:34 -0000
@@ -72,17 +72,17 @@ function newSubmition($errors)
         echo "   and click on &#8216;Submit new version&#8217;</li>\n";
     }
     echo " <li>Entered a valid version for this application.  This is the application\n";
-    echo "   version, NOT the Wine version (which goes in the testing results section of the template)</li>\n";
+    echo "   version, NOT the Wine version (which goes in the test results section of the template)</li>\n";
     echo " <li>Tested this application under Wine.  There are tens of thousands of applications\n";
     echo "   for Windows, we do not need placeholder entries in the database.  Please enter as complete \n";
-    echo "   as possible testing results in the version template provided below</li>\n";
+    echo "   as possible test results in the version template provided below</li>\n";
     echo "</ul></p>";
     echo "<p>Please do not forget to mention which Wine version you used, how well it worked\n";
     echo "and if any workarounds were needed.  Having app descriptions just sponsoring the app\n";
     echo "(yes, some vendors want to use the appdb for this) or saying &#8216;I haven&#8217;t tried this app with Wine&#8217; ";
     echo "will not help Wine development or Wine users.</p>\n";
     echo "<b><span style=\"color:red\">Please only submit applications/versions that you have tested.\n";
-    echo "Submissions without testing information or not using the provided template will be rejected.\n";
+    echo "Submissions without test information or not using the provided template will be rejected.\n";
     echo "If you are unable to see the in-browser editors below, please try Firefox, Mozilla or Opera browsers.\n</span></b>";
     echo "<p>After your application has been added, you will be able to submit screenshots for it, post";
     echo " messages in its forums or become a maintainer to help others trying to run the application.</p>";
@@ -139,7 +139,7 @@ if ($aClean['sSub'])
         util_redirect_and_exit($_SERVER['PHP_SELF']);
     }
 
     // Get the Testing results if they exist
     $hResult = query_parameters("Select testingId from testResults where versionId = '?'",
                             $oVersion->iVersionId);
     if($hResult)
@@ -139,7 +139,7 @@ if ($aClean['sSub'])
     }
 
-    // Get the Testing results if they exist
+    // Get the Test results if they exist
     $hResult = query_parameters("Select testingId from testResults where versionId = '?'",
                             $oVersion->iVersionId);
Index: include/distribution.php
===================================================================
RCS file: /home/wine/appdb/include/distribution.php,v
retrieving revision 1.1
diff -u -p -r1.1 distribution.php
--- include/distribution.php	21 Jul 2006 04:21:04 -0000	1.1
+++ include/distribution.php	24 Oct 2006 22:54:34 -0000
@@ -5,7 +5,7 @@
 require_once(BASE."include/mail.php");
 require_once(BASE."include/util.php");
 
 // Testing class for handling Distributions.
 
 class distribution{
     var $iDistributionId;
@@ -179,7 +179,7 @@ class distribution{
                             "false", $this->iDistributionId))
         {
             $this->sQueued = 'false';
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             $this->mailSubmitter("unQueue");
             $this->SendNotificationMail();
             return true;
@@ -206,7 +206,7 @@ class distribution{
                             "rejected", $this->iDistributionId))
         {
             $this->sQueued = 'rejected';
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             if(!$bSilent)
             {
                 $this->mailSubmitter("reject");
@@ -237,10 +237,10 @@ class distribution{
                                 "true", $this->iDistributionId))
             {
                 $this->sQueued = 'true';
-                // we send an e-mail to intersted people
+                // we send an e-mail to interested people
                 $this->SendNotificationMail();
 
                 // the testing data has been resubmitted
                 addmsg("The Distribution has been resubmitted", "green");
                 return true;
             }
@@ -317,10 +317,10 @@ class distribution{
                         $sMsg .= $aClean['sReplyText']."\n"; // append the reply text, if there is any 
                     }
                     addmsg("The Distribution was successfully added into the database.", "green");
-                } else // testing data queued.
+                } else // test data queued.
                 {
                     $sSubject = "Distribution ".$this->sName." submitted by ".$_SESSION['current']->sRealname;
-                    $sMsg .= "This testing data has been queued.";
+                    $sMsg .= "This test data has been queued.";
                     $sMsg .= "\n";
                     addmsg("The Distribution you submitted will be added to the database after being reviewed.", "green");
                 }
@@ -5,7 +5,7 @@
 require_once(BASE."include/util.php");
 
-// Testing class for handling Distributions.
+// Test class for handling Distributions.
 
 class distribution{
@@ -237,10 +237,10 @@ class distribution{
                 $this->SendNotificationMail();
 
-                // the testing data has been resubmitted
+                // the test data has been resubmitted
                 addmsg("The Distribution has been resubmitted", "green");
                 return true;
Index: include/testData.php
===================================================================
RCS file: /home/wine/appdb/include/testData.php,v
retrieving revision 1.9
diff -u -p -r1.9 testData.php
--- include/testData.php	31 Aug 2006 02:39:09 -0000	1.9
+++ include/testData.php	24 Oct 2006 22:54:34 -0000
@@ -1,10 +1,10 @@
 <?php
 /*****************************************/
 /* this class represents Testing results */
 /*****************************************/
 require_once(BASE."include/distribution.php");
 require_once(BASE."include/util.php");
 // Class for handling Testing History.
 
 class testData{
     var $iTestingId;
@@ -61,7 +61,7 @@ class testData{
     // Creates a new Test Results.
     function create()
     {
-        // Security, if we are not an administrator or an maintainer the test result must be queued.
+        // Security, if we are not an administrator or a maintainer the test result must be queued.
         $oVersion = new Version($oTest->iVersionId);
         if(!$_SESSION['current']->hasPriv("admin") && 
            !$_SESSION['current']->hasAppVersionModifyPermission($oVersion))
@@ -97,7 +97,7 @@ class testData{
     // Update Test Results.
     function update($bSilent=false)
     {
         // is the current user allowed to update this testing result? 
         $oVersion = new Version($this->iVersionId);
         if(!$_SESSION['current']->hasPriv("admin") && 
            !$_SESSION['current']->hasAppVersionModifyPermission($oVersion) &&
@@ -143,10 +143,10 @@ class testData{
         }
     }
     
     // Delete testing results.
     function delete($bSilent=false)
     {
         // is the current user allowed to delete this testing result? 
         $oVersion = new Version($this->iVersionId);
         if(!$_SESSION['current']->hasPriv("admin") && 
            !$_SESSION['current']->hasAppVersionModifyPermission($oVersion) &&
@@ -154,13 +154,13 @@ class testData{
         {
             return;
         }
         // now delete the testing data 
         $sQuery = "DELETE FROM testResults
                    WHERE testingId = '?' 
                    LIMIT 1";
         if(!($hResult = query_parameters($sQuery, $this->iTestingId)))
         {
-            addmsg("Error removing the deleted testing data!", "red");
+            addmsg("Error removing the deleted test data!", "red");
         }
 
         if(!$bSilent)
@@ -170,10 +170,10 @@ class testData{
     }
 
 
     // Move Testing Data out of the queue.
     function unQueue()
     {
         // is the current user allowed to delete this testing data? 
         $oVersion = new Version($this->iVersionId);
         if(!$_SESSION['current']->hasPriv("admin") &&
            !$_SESSION['current']->hasAppVersionModifyPermission($oVersion))
@@ -181,7 +181,7 @@ class testData{
             return;
         }
 
         // If we are not in the queue, we can't move the testing data out of the queue.
         if(!$this->sQueued == 'true')
             return false;
 
@@ -189,7 +189,7 @@ class testData{
                             "false", $this->iTestingId))
         {
             $this->sQueued = 'false';
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             $this->mailSubmitter("unQueue");
             $this->SendNotificationMail();
         }
@@ -197,7 +197,7 @@ class testData{
 
     function Reject()
     {
         // is the current user allowed to delete this testing data? 
         $oVersion = new Version($this->iVersionId);
         if(!$_SESSION['current']->hasPriv("admin") &&
            !$_SESSION['current']->hasAppVersionModifyPermission($oVersion))
@@ -213,7 +213,7 @@ class testData{
                             "rejected", $this->iTestingId))
         {
             $this->sQueued = 'rejected';
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             $this->mailSubmitter("reject");
             $this->SendNotificationMail("reject");
         }
@@ -234,7 +234,7 @@ class testData{
                             "true", $this->iTestingId))
         {
             $this->sQueued = 'true';
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             $this->SendNotificationMail();
         }
     }
@@ -252,20 +252,20 @@ class testData{
             switch($sAction)
             {
             case "add":
-                $sSubject =  "Submitted testing data accepted";
-                $sMsg  = "The testing data you submitted (".$oApp->sName." ".$this->sName.") has been accepted.";
+                $sSubject =  "Submitted test data accepted";
+                $sMsg  = "The test data you submitted (".$oApp->sName." ".$this->sName.") has been accepted.";
                 $sMsg .= APPDB_ROOT."appview.php?iVersionId=".$this->iVersionId."&iTestingId=".$this->iTestingId."\n";
-                $sMsg .= "Administrators Responce:\n";
+                $sMsg .= "Administrators Response:\n";
             break;
             case "reject":
-                $sSubject =  "Submitted testing data rejected";
-                $sMsg  = "The testing data you submitted (".$oApp->sName." ".$this->sName.") has been rejected.";
+                $sSubject =  "Submitted test data rejected";
+                $sMsg  = "The test data you submitted (".$oApp->sName." ".$this->sName.") has been rejected.";
                 $sMsg .= APPDB_ROOT."testResults.php?sSub=view&iTestingId=".$this->iTestingId."\n";
                 $sMsg .= "Reason given:\n";
             break;
             case "delete":
-                $sSubject =  "Submitted testing data deleted";
-                $sMsg  = "The testing data you submitted (".$oApp->sName." ".$this->sName.") has been deleted.";
+                $sSubject =  "Submitted test data deleted";
+                $sMsg  = "The test data you submitted (".$oApp->sName." ".$this->sName.") has been deleted.";
                 $sMsg .= "Reason given:\n";
             break;
             }
@@ -297,7 +297,7 @@ class testData{
                     if($this->iSubmitterId)
                     {
                         $oSubmitter = new User($this->iSubmitterId);
-                        $sMsg .= "This Testing data has been submitted by ".$oSubmitter->sRealname.".";
+                        $sMsg .= "This Test data has been submitted by ".$oSubmitter->sRealname.".";
                         $sMsg .= "\n";
                     }
                     if($aClean['sReplyText'])
@@ -305,20 +305,20 @@ class testData{
                         $sMsg .= "Appdb admin reply text:\n";
                         $sMsg .= $aClean['sReplyText']."\n"; // append the reply text, if there is any 
                     }
-                    addmsg("The testing data was successfully added into the database.", "green");
-                } else // testing data queued.
+                    addmsg("The test data was successfully added into the database.", "green");
+                } else // test data queued.
                 {
                     $sSubject = "Test Results submitted for version ".$oVersion->sName." of ".$oApp->sName." submitted by ".$_SESSION['current']->sRealname;
                     $sMsg  .= $sBacklink;
-                    $sMsg .= "This testing data has been queued.";
+                    $sMsg .= "This test data has been queued.";
                     $sMsg .= "\n";
-                    addmsg("The testing data you submitted will be added to the database after being reviewed.", "green");
+                    addmsg("The test data you submitted will be added to the database after being reviewed.", "green");
                 }
             break;
             case "edit":
                 $sSubject = "Test Results modified for version ".$oVersion->sName." of ".$oApp->sName." submitted by ".$_SESSION['current']->sRealname;
                 $sMsg  .= $sBacklink;
-                addmsg("testing data modified.", "green");
+                addmsg("test data modified.", "green");
             break;
             case "delete":
                 $sSubject = "Test Results deleted for version ".$oVersion->sName." of ".$oApp->sName." submitted by ".$_SESSION['current']->sRealname;
@@ -329,7 +329,7 @@ class testData{
                     $sMsg .= $aClean['sReplyText']."\n"; // append the reply text, if there is any 
                 }
 
-                addmsg("testing data deleted.", "green");
+                addmsg("test data deleted.", "green");
             break;
             case "reject":
                 $sSubject = "Test Results rejected for version ".$oVersion->sName." of ".$oApp->sName." submitted by ".$_SESSION['current']->sRealname;
@@ -340,7 +340,7 @@ class testData{
                     $sMsg .= "Reason given:\n";
                     $sMsg .= $aClean['sReplyText']."\n"; // append the reply text, if there is any 
                 }
-                addmsg("testing data rejected.", "green");
+                addmsg("test data rejected.", "green");
             break;
         }
         $sEmail = User::get_notify_email_address_list(null, $this->iVersionId);
@@ -388,7 +388,7 @@ class testData{
 
         if($rowsUsed == 0)
              return;
-        echo '<p><span class="title">Testing Results</span><br />',"\n";
+        echo '<p><span class="title">Test Results</span><br />',"\n";
         echo '<table width="100%" border="1" class="historyTable">',"\n";
         echo '<thead class="historyHeader">',"\n";
         echo '<tr>',"\n";
@@ -490,7 +490,7 @@ class testData{
     {
         HtmlAreaLoaderScript(array("Test1", "Test2", "Test3"));
 
-        echo html_frame_start("Testing Form", "90%", "", 0);
+        echo html_frame_start("Test Form", "90%", "", 0);
         echo "<table width='100%' border=0 cellpadding=2 cellspacing=0>\n";
 
         // What works
@@ -644,7 +644,7 @@ class testData{
         {
             $oTest = new testData($oRow->testingId);
             $oVersion = new Version($oTest->iVersionId);
             // dont show testing results of versions that are still queued.
             if ($oVersion->sQueued == 'false')
             {
                 $oApp  = new Application($oVersion->iAppId);
@@ -1,10 +1,10 @@
 <?php
 /*****************************************/
-/* this class represents Testing results */
+/* this class represents Test results    */
 /*****************************************/
 require_once(BASE."include/distribution.php");
@@ -1,10 +1,10 @@
 require_once(BASE."include/distribution.php");
 require_once(BASE."include/util.php");
-// Class for handling Testing History.
+// Class for handling Test History.
 
 class testData{
@@ -97,7 +97,7 @@ class testData{
     function update($bSilent=false)
     {
-        // is the current user allowed to update this testing result? 
+        // is the current user allowed to update this test result? 
         $oVersion = new Version($this->iVersionId);
         if(!$_SESSION['current']->hasPriv("admin") && 
@@ -143,10 +143,10 @@ class testData{
     }
     
-    // Delete testing results.
+    // Delete test results.
     function delete($bSilent=false)
     {
@@ -143,10 +143,10 @@ class testData{
     function delete($bSilent=false)
     {
-        // is the current user allowed to delete this testing result? 
+        // is the current user allowed to delete this test result? 
         $oVersion = new Version($this->iVersionId);
         if(!$_SESSION['current']->hasPriv("admin") && 
@@ -154,13 +154,13 @@ class testData{
             return;
         }
-        // now delete the testing data 
+        // now delete the test data 
         $sQuery = "DELETE FROM testResults
                    WHERE testingId = '?' 
@@ -170,10 +170,10 @@ class testData{
 
 
-    // Move Testing Data out of the queue.
+    // Move Test Data out of the queue.
     function unQueue()
     {
@@ -170,10 +170,10 @@ class testData{
     function unQueue()
     {
-        // is the current user allowed to delete this testing data? 
+        // is the current user allowed to delete this test data? 
         $oVersion = new Version($this->iVersionId);
         if(!$_SESSION['current']->hasPriv("admin") &&
@@ -181,7 +181,7 @@ class testData{
         }
 
-        // If we are not in the queue, we can't move the testing data out of the queue.
+        // If we are not in the queue, we can't move the test data out of the queue.
         if(!$this->sQueued == 'true')
             return false;
@@ -197,7 +197,7 @@ class testData{
     function Reject()
     {
-        // is the current user allowed to delete this testing data? 
+        // is the current user allowed to delete this test data? 
         $oVersion = new Version($this->iVersionId);
         if(!$_SESSION['current']->hasPriv("admin") &&
@@ -644,7 +644,7 @@ class testData{
             $oTest = new testData($oRow->testingId);
             $oVersion = new Version($oTest->iVersionId);
-            // dont show testing results of versions that are still queued.
+            // don't show test results of versions that are still queued.
             if ($oVersion->sQueued == 'false')
             {
Index: include/version.php
===================================================================
RCS file: /home/wine/appdb/include/version.php,v
retrieving revision 1.82
diff -u -p -r1.82 version.php
--- include/version.php	26 Sep 2006 02:09:26 -0000	1.82
+++ include/version.php	24 Oct 2006 22:54:34 -0000
@@ -344,7 +344,7 @@ class Version {
                             "false", $this->iVersionId))
         {
             $this->sQueued = 'false';
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             $this->mailSubmitter("unQueue");
             $this->SendNotificationMail();
         }
@@ -363,7 +363,7 @@ class Version {
                             "rejected", $this->iVersionId))
         {
             $this->sQueued = 'rejected';
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             if(!$bSilent)
             {
                 $this->mailSubmitter("reject");
@@ -383,7 +383,7 @@ class Version {
                             "true", $this->iVersionId))
         {
             $this->sQueued = 'true';
-            // we send an e-mail to intersted people
+            // we send an e-mail to interested people
             $this->SendNotificationMail();
 
             // the version has been unqueued
@@ -405,7 +405,7 @@ class Version {
             case "add":
                 $sSubject =  "Submitted version accepted";
                 $sMsg  = "The version you submitted (".$oApp->sName." ".$this->sName.") has been accepted.";
-                $sMsg .= "Administrators Responce:\n";
+                $sMsg .= "Administrators Response:\n";
             break;
             case "reject":
                 $sSubject =  "Submitted version rejected";
@@ -783,14 +783,14 @@ class Version {
         echo $this->sDescription;
 
 
         // Show testing data
 
         $oTest = new testData($iTestingId);
 
         /* if $iTestingId wasn't valid then it won't be valid in $oTest */
         if(!$oTest->iTestingId)
         {
             /* fetch a new testing id for this version */
             $iTestingId = testData::get_test_for_versionid($this->iVersionId);
             $oTest = new testData($iTestingId);
         }
@@ -804,13 +804,13 @@ class Version {
         if($_SESSION['current']->isLoggedIn())
         {
             echo '<form method=post name=sMessage action=testResults.php?sSub=view&iVersionId='.$this->iVersionId.'>';
-            echo '<input type=submit value="Add Testing Data" class="button" />';
+            echo '<input type=submit value="Add Test Data" class="button" />';
             echo '</form>';
         } else
         {
             echo '<form method="post" name="sMessage" action="account.php">';
             echo '<input type="hidden" name="sCmd" value="login">';
-            echo '<input type=submit value="Log in add Testing Data" class="button">';
+            echo '<input type=submit value="Log in add Test Data" class="button">';
             echo '</form>';
         }
         echo "</td></tr>";
@@ -783,14 +783,14 @@ class Version {
 
 
-        // Show testing data
+        // Show test data
 
         $oTest = new testData($iTestingId);
@@ -783,14 +783,14 @@ class Version {
         if(!$oTest->iTestingId)
         {
-            /* fetch a new testing id for this version */
+            /* fetch a new test id for this version */
             $iTestingId = testData::get_test_for_versionid($this->iVersionId);
             $oTest = new testData($iTestingId);